@@ -24,14 +24,14 @@ test_that("Matrix [-, %*%, sum, prod]",
   b <- parm(matrix(2:5, 2, 2), name = "b")
 
   # Create test expression
-  c <- cg.prod(cg.matmul(a, b)) * cg.sum(cg.matmul(a, b))
+  c <- cg_prod(cg_matmul(a, b)) * cg_sum(cg_matmul(a, b))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
 
 test_that("Matrix [+, mean, crossprod, tcrossprod]",
@@ -44,14 +44,14 @@ test_that("Matrix [+, mean, crossprod, tcrossprod]",
   b <- parm(matrix(2:5, 2, 2), name = "b")
 
   # Create test expression
-  c <- cg.mean(cg.crossprod(a, b) + cg.tcrossprod(a, b))
+  c <- cg_mean(cg_crossprod(a, b) + cg_tcrossprod(a, b) + cg_crossprod(a) + cg_tcrossprod(b))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
 
 test_that("Matrix [linear, rowSums, colSums]",
@@ -64,14 +64,14 @@ test_that("Matrix [linear, rowSums, colSums]",
   b <- parm(matrix(2:5, 2, 2), name = "b")
 
   # Create test expression
-  c <- cg.rowSums(cg.linear(a, b, cg.colSums(b)))
+  c <- cg_rowSums(cg_linear(a, b, cg_colSums(b)))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
 
 test_that("Array [*, rowMeans, colMeans]",
@@ -84,14 +84,14 @@ test_that("Array [*, rowMeans, colMeans]",
   b <- parm(array(2:25, 2:4), name = "b")
 
   # Create test expression
-  c <- cg.rowMeans(a) * cg.colMeans(b)
+  c <- cg_rowMeans(a) * cg_colMeans(b)
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
 
 test_that("Matrix [*, max, min]",
@@ -104,14 +104,14 @@ test_that("Matrix [*, max, min]",
   b <- parm(matrix(2:5, 2, 2), name = "b")
 
   # Create test expression
-  c <- cg.max(a) * cg.min(b)
+  c <- cg_max(a) * cg_min(b)
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
 
 test_that("Matrix [*, pmax, pmin]",
@@ -124,12 +124,12 @@ test_that("Matrix [*, pmax, pmin]",
   b <- parm(matrix(2:5, 2, 2), name = "b")
 
   # Create test expression
-  c <- cg.pmax(a, b) * cg.pmin(a, b)
+  c <- cg_pmax(a, b) * cg_pmin(a, b)
 
   # Calculate gradients
   grads <- gradients(c, run(c))
 
   # Check gradients
-  expect_equivalent(grads$a, approx.grad(c, a), tolerance = 1e-4)
-  expect_equivalent(grads$b, approx.grad(c, b), tolerance = 1e-4)
+  expect_equivalent(grads$a, approx_grad(c, a), tolerance = 1e-4)
+  expect_equivalent(grads$b, approx_grad(c, b), tolerance = 1e-4)
 })
